Module Name:    src
Committed By:   rillig
Date:           Fri Dec 18 15:47:34 UTC 2020

Modified Files:
        src/usr.bin/make: arch.c make.c suff.c targ.c
        src/usr.bin/make/PSD.doc: tutorial.ms
        src/usr.bin/make/unit-tests: depsrc-optional.exp

Log Message:
make(1): spell nonexistent consistently


To generate a diff of this commit:
cvs rdiff -u -r1.188 -r1.189 src/usr.bin/make/arch.c
cvs rdiff -u -r1.230 -r1.231 src/usr.bin/make/make.c
cvs rdiff -u -r1.330 -r1.331 src/usr.bin/make/suff.c
cvs rdiff -u -r1.158 -r1.159 src/usr.bin/make/targ.c
cvs rdiff -u -r1.13 -r1.14 src/usr.bin/make/PSD.doc/tutorial.ms
cvs rdiff -u -r1.6 -r1.7 src/usr.bin/make/unit-tests/depsrc-optional.exp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/make/arch.c
diff -u src/usr.bin/make/arch.c:1.188 src/usr.bin/make/arch.c:1.189
--- src/usr.bin/make/arch.c:1.188	Sun Dec 13 20:14:48 2020
+++ src/usr.bin/make/arch.c	Fri Dec 18 15:47:34 2020
@@ -1,4 +1,4 @@
-/*	$NetBSD: arch.c,v 1.188 2020/12/13 20:14:48 rillig Exp $	*/
+/*	$NetBSD: arch.c,v 1.189 2020/12/18 15:47:34 rillig Exp $	*/
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -125,7 +125,7 @@
 #include "config.h"
 
 /*	"@(#)arch.c	8.2 (Berkeley) 1/2/94"	*/
-MAKE_RCSID("$NetBSD: arch.c,v 1.188 2020/12/13 20:14:48 rillig Exp $");
+MAKE_RCSID("$NetBSD: arch.c,v 1.189 2020/12/18 15:47:34 rillig Exp $");
 
 typedef struct List ArchList;
 typedef struct ListNode ArchListNode;
@@ -903,7 +903,7 @@ Arch_UpdateMTime(GNode *gn)
 		gn->mtime = 0;
 }
 
-/* Given a non-existent archive member's node, update gn->mtime from its
+/* Given a nonexistent archive member's node, update gn->mtime from its
  * archived form, if it exists. */
 void
 Arch_UpdateMemberMTime(GNode *gn)

Index: src/usr.bin/make/suff.c
diff -u src/usr.bin/make/suff.c:1.330 src/usr.bin/make/suff.c:1.331
--- src/usr.bin/make/suff.c:1.330	Sun Dec 13 20:14:48 2020
+++ src/usr.bin/make/suff.c	Fri Dec 18 15:47:34 2020
@@ -1,4 +1,4 @@
-/*	$NetBSD: suff.c,v 1.330 2020/12/13 20:14:48 rillig Exp $	*/
+/*	$NetBSD: suff.c,v 1.331 2020/12/18 15:47:34 rillig Exp $	*/
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -114,7 +114,7 @@
 #include "dir.h"
 
 /*	"@(#)suff.c	8.4 (Berkeley) 3/21/94"	*/
-MAKE_RCSID("$NetBSD: suff.c,v 1.330 2020/12/13 20:14:48 rillig Exp $");
+MAKE_RCSID("$NetBSD: suff.c,v 1.331 2020/12/18 15:47:34 rillig Exp $");
 
 typedef List SuffixList;
 typedef ListNode SuffixListNode;
@@ -2012,7 +2012,7 @@ CandidateSearcher_CleanUp(CandidateSearc
  * is set for the given node and all its implied children.
  *
  * The path found by this target is the shortest path in the transformation
- * graph, which may pass through non-existent targets, to an existing target.
+ * graph, which may pass through nonexistent targets, to an existing target.
  * The search continues on all paths from the root suffix until a file is
  * found. I.e. if there's a path .o -> .c -> .l -> .l,v from the root and the
  * .l,v file exists but the .c and .l files don't, the search will branch out

Index: src/usr.bin/make/targ.c
diff -u src/usr.bin/make/targ.c:1.158 src/usr.bin/make/targ.c:1.159
--- src/usr.bin/make/targ.c:1.158	Fri Dec 18 14:46:44 2020
+++ src/usr.bin/make/targ.c	Fri Dec 18 15:47:34 2020
@@ -1,4 +1,4 @@
-/*	$NetBSD: targ.c,v 1.158 2020/12/18 14:46:44 rillig Exp $	*/
+/*	$NetBSD: targ.c,v 1.159 2020/12/18 15:47:34 rillig Exp $	*/
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -113,7 +113,7 @@
 #include "dir.h"
 
 /*	"@(#)targ.c	8.2 (Berkeley) 3/19/94"	*/
-MAKE_RCSID("$NetBSD: targ.c,v 1.158 2020/12/18 14:46:44 rillig Exp $");
+MAKE_RCSID("$NetBSD: targ.c,v 1.159 2020/12/18 15:47:34 rillig Exp $");
 
 /*
  * All target nodes that appeared on the left-hand side of one of the
@@ -507,7 +507,7 @@ Targ_PrintNode(GNode *gn, int pass)
 				    Targ_FmtTime(gn->mtime),
 				    made_name(gn->made));
 			} else if (gn->made != UNMADE) {
-				debug_printf("# non-existent (maybe): %s\n",
+				debug_printf("# nonexistent (maybe): %s\n",
 				    made_name(gn->made));
 			} else
 				debug_printf("# unmade\n");

Index: src/usr.bin/make/PSD.doc/tutorial.ms
diff -u src/usr.bin/make/PSD.doc/tutorial.ms:1.13 src/usr.bin/make/PSD.doc/tutorial.ms:1.14
--- src/usr.bin/make/PSD.doc/tutorial.ms:1.13	Wed Mar  1 13:05:11 2017
+++ src/usr.bin/make/PSD.doc/tutorial.ms	Fri Dec 18 15:47:34 2020
@@ -1,4 +1,4 @@
-.\"	$NetBSD: tutorial.ms,v 1.13 2017/03/01 13:05:11 kre Exp $
+.\"	$NetBSD: tutorial.ms,v 1.14 2020/12/18 15:47:34 rillig Exp $
 .\" Copyright (c) 1988, 1989, 1993
 .\"	The Regents of the University of California.  All rights reserved.
 .\"
@@ -1918,15 +1918,15 @@ Suff_FindDeps (jive.c)
 	applying .l -> .c to "jive.l"
 Suff_FindDeps (jive.l)
 Examining jive.l...modified 17:16:01 Oct 4, 1987...up-to-date
-Examining jive.c...non-existent...out-of-date
+Examining jive.c...nonexistent...out-of-date
 --- jive.c ---
 lex jive.l
 \&.\|.\|. meaningless lex output deleted .\|.\|.
 mv lex.yy.c jive.c
-Examining jive.o...non-existent...out-of-date
+Examining jive.o...nonexistent...out-of-date
 --- jive.o ---
 cc -c jive.c
-Examining jive.out...non-existent...out-of-date
+Examining jive.out...nonexistent...out-of-date
 --- jive.out ---
 cc -o jive.out jive.o
 .DE
@@ -2871,7 +2871,7 @@ current directory. While people have sug
 the directories each time, my experience suggests that the caching seldom
 causes problems. In addition, not caching the directories slows things
 down enormously because of PMake's attempts to apply transformation
-rules through non-existent files \*- the number of extra file-system
+rules through nonexistent files \*- the number of extra file-system
 searches is truly staggering, especially if many files without
 suffixes are used and the null suffix isn't changed from
 .CW .out .

Index: src/usr.bin/make/unit-tests/depsrc-optional.exp
diff -u src/usr.bin/make/unit-tests/depsrc-optional.exp:1.6 src/usr.bin/make/unit-tests/depsrc-optional.exp:1.7
--- src/usr.bin/make/unit-tests/depsrc-optional.exp:1.6	Fri Dec 18 14:46:44 2020
+++ src/usr.bin/make/unit-tests/depsrc-optional.exp	Fri Dec 18 15:47:34 2020
@@ -5,16 +5,16 @@ ExamineLater: need to examine "optional"
 ExamineLater: need to examine "optional-cohort"
 Make_ExpandUse: examine optional
 Make_ExpandUse: examine optional-cohort
-Examining optional...non-existent...up-to-date.
-Examining optional-cohort...non-existent...:: operator and no sources...out-of-date.
+Examining optional...nonexistent...up-to-date.
+Examining optional-cohort...nonexistent...:: operator and no sources...out-of-date.
 : A leaf node using '::' is considered out-of-date.
  recheck(optional-cohort): update time from nonexistent to now
-Examining important...non-existent...modified before source "optional-cohort"...out-of-date.
+Examining important...nonexistent...modified before source "optional-cohort"...out-of-date.
 : important is made.
  recheck(important): update time from nonexistent to now
-Examining all...non-existent...modified before source "important"...out-of-date.
+Examining all...nonexistent...modified before source "important"...out-of-date.
 : all is made.
  recheck(all): update time from nonexistent to now
-Examining .END...non-existent...non-existent and no sources...out-of-date.
+Examining .END...nonexistent...nonexistent and no sources...out-of-date.
  recheck(.END): update time from nonexistent to now
 exit status 0

Reply via email to
Index: src/usr.bin/make/make.c
diff -u src/usr.bin/make/make.c:1.230 src/usr.bin/make/make.c:1.231
--- src/usr.bin/make/make.c:1.230	Fri Dec 18 14:46:44 2020
+++ src/usr.bin/make/make.c	Fri Dec 18 15:47:34 2020
@@ -1,4 +1,4 @@
-/*	$NetBSD: make.c,v 1.230 2020/12/18 14:46:44 rillig Exp $	*/
+/*	$NetBSD: make.c,v 1.231 2020/12/18 15:47:34 rillig Exp $	*/
 
 /*
  * Copyright (c) 1988, 1989, 1990, 1993
@@ -102,7 +102,7 @@
 #include "job.h"
 
 /*	"@(#)make.c	8.1 (Berkeley) 6/6/93"	*/
-MAKE_RCSID("$NetBSD: make.c,v 1.230 2020/12/18 14:46:44 rillig Exp $");
+MAKE_RCSID("$NetBSD: make.c,v 1.231 2020/12/18 15:47:34 rillig Exp $");
 
 /* Sequence # to detect recursion. */
 static unsigned int checked_seqno = 1;
@@ -202,7 +202,7 @@ IsOODateRegular(GNode *gn)
 	}
 
 	if (gn->mtime == 0 && !(gn->type & OP_OPTIONAL)) {
-		DEBUG0(MAKE, "non-existent and no sources...");
+		DEBUG0(MAKE, "nonexistent and no sources...");
 		return TRUE;
 	}
 
@@ -241,7 +241,7 @@ GNode_IsOODate(GNode *gn)
 				debug_printf("modified %s...",
 				    Targ_FmtTime(gn->mtime));
 			else
-				debug_printf("non-existent...");
+				debug_printf("nonexistent...");
 		}
 	}
 
@@ -275,7 +275,7 @@ GNode_IsOODate(GNode *gn)
 
 		/*
 		 * always out of date if no children and :: target
-		 * or non-existent.
+		 * or nonexistent.
 		 */
 		oodate = (gn->mtime == 0 || Arch_LibOODate(gn) ||
 			  (gn->youngestChild == NULL &&
@@ -309,10 +309,10 @@ GNode_IsOODate(GNode *gn)
 		oodate = TRUE;
 	} else {
 		/*
 		 * When a non-existing child with no sources
 		 * (such as a typically used FORCE source) has been made and
 		 * the target of the child (usually a directory) has the same
 		 * timestamp as the timestamp just given to the non-existing
 		 * child after it was considered made.
 		 */
 		if (DEBUG(MAKE)) {
@@ -309,10 +309,10 @@ GNode_IsOODate(GNode *gn)
 	} else {
 		/*
-		 * When a non-existing child with no sources
+		 * When a nonexistent child with no sources
 		 * (such as a typically used FORCE source) has been made and
 		 * the target of the child (usually a directory) has the same
@@ -309,10 +309,10 @@ GNode_IsOODate(GNode *gn)
 		 * (such as a typically used FORCE source) has been made and
 		 * the target of the child (usually a directory) has the same
-		 * timestamp as the timestamp just given to the non-existing
+		 * timestamp as the timestamp just given to the nonexistent
 		 * child after it was considered made.
 		 */
